==> okareo-0.0.47-py3-none-any.whl: okareo_api_client/api/default/get_datapoints_summary_v0_summary_datapoints_post.py <==
from http import HTTPStatus
from typing import Any, Dict, List, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.datapoint_summary_item import DatapointSummaryItem
from ...models.error_response import ErrorResponse
from ...models.summary_datapoint_search import SummaryDatapointSearch
from ...types import Response


def _get_kwargs(
    *,
    json_body: SummaryDatapointSearch,
    api_key: str,
) -> Dict[str, Any]:
    headers = {}
    headers["api-key"] = api_key

    json_json_body = json_body.to_dict()

    return {
        "method": "post",
        "url": "/v0/summary_datapoints",
        "json": json_json_body,
        "headers": headers,
    }


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[ErrorResponse, List["DatapointSummaryItem"]]]:
    if response.status_code == HTTPStatus.OK:
        response_200 = []
        _response_200 = response.json()
        for response_200_item_data in _response_200:
            response_200_item = DatapointSummaryItem.from_dict(response_200_item_data)

            response_200.append(response_200_item)

        return response_200
    if response.status_code == HTTPStatus.BAD_REQUEST:
        response_400 = ErrorResponse.from_dict(response.json())

        return response_400
    if response.status_code == HTTPStatus.NOT_FOUND:
        response_404 = ErrorResponse.from_dict(response.json())

        return response_404
    if response.status_code == HTTPStatus.UNPROCESSABLE_ENTITY:
        response_422 = ErrorResponse.from_dict(response.json())

        return response_422
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[ErrorResponse, List["DatapointSummaryItem"]]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    json_body: SummaryDatapointSearch,
    api_key: str,
) -> Response[Union[ErrorResponse, List["DatapointSummaryItem"]]]:
    """Get Datapoints Summary

     Expects a date range and returns a summary of datapoint counts by day and feedback range.

    Returns:
        list: An array of datapoint objects.

    Args:
        api_key (str):
        json_body (SummaryDatapointSearch):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[ErrorResponse, List['DatapointSummaryItem']]]
    """

    kwargs = _get_kwargs(
        json_body=json_body,
        api_key=api_key,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: Union[AuthenticatedClient, Client],
    json_body: SummaryDatapointSearch,
    api_key: str,
) -> Optional[Union[ErrorResponse, List["DatapointSummaryItem"]]]:
    """Get Datapoints Summary

     Expects a date range and returns a summary of datapoint counts by day and feedback range.

    Returns:
        list: An array of datapoint objects.

    Args:
        api_key (str):
        json_body (SummaryDatapointSearch):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[ErrorResponse, List['DatapointSummaryItem']]
    """

    return sync_detailed(
        client=client,
        json_body=json_body,
        api_key=api_key,
    ).parsed


async def asyncio_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    json_body: SummaryDatapointSearch,
    api_key: str,
) -> Response[Union[ErrorResponse, List["DatapointSummaryItem"]]]:
    """Get Datapoints Summary

     Expects a date range and returns a summary of datapoint counts by day and feedback range.

    Returns:
        list: An array of datapoint objects.

    Args:
        api_key (str):
        json_body (SummaryDatapointSearch):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[ErrorResponse, List['DatapointSummaryItem']]]
    """

    kwargs = _get_kwargs(
        json_body=json_body,
        api_key=api_key,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: Union[AuthenticatedClient, Client],
    json_body: SummaryDatapointSearch,
    api_key: str,
) -> Optional[Union[ErrorResponse, List["DatapointSummaryItem"]]]:
    """Get Datapoints Summary

     Expects a date range and returns a summary of datapoint counts by day and feedback range.

    Returns:
        list: An array of datapoint objects.

    Args:
        api_key (str):
        json_body (SummaryDatapointSearch):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[ErrorResponse, List['DatapointSummaryItem']]
    """

    return (
        await asyncio_detailed(
            client=client,
            json_body=json_body,
            api_key=api_key,
        )
    ).parsed

==> okareo-0.0.69-py3-none-any.whl: okareo_api_client/api/default/get_datapoints_summary_v0_summary_datapoints_post.py <==
from http import HTTPStatus
from typing import Any, Dict, List, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.datapoint_summary_item import DatapointSummaryItem
from ...models.error_response import ErrorResponse
from ...models.summary_datapoint_search import SummaryDatapointSearch
from ...types import Response


def _get_kwargs(
    *,
    json_body: SummaryDatapointSearch,
    api_key: str,
) -> Dict[str, Any]:
    headers = {}
    headers["api-key"] = api_key

    json_json_body = json_body.to_dict()

    return {
        "method": "post",
        "url": "/v0/summary_datapoints",
        "json": json_json_body,
        "headers": headers,
    }


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[ErrorResponse, List["DatapointSummaryItem"]]]:
    if response.status_code == HTTPStatus.OK:
        response_200 = []
        _response_200 = response.json()
        for response_200_item_data in _response_200:
            response_200_item = DatapointSummaryItem.from_dict(response_200_item_data)

            response_200.append(response_200_item)

        return response_200
    if response.status_code == HTTPStatus.BAD_REQUEST:
        response_400 = ErrorResponse.from_dict(response.json())

        return response_400
    if response.status_code == HTTPStatus.UNAUTHORIZED:
        response_401 = ErrorResponse.from_dict(response.json())

        return response_401
    if response.status_code == HTTPStatus.NOT_FOUND:
        response_404 = ErrorResponse.from_dict(response.json())

        return response_404
    if response.status_code == HTTPStatus.UNPROCESSABLE_ENTITY:
        response_422 = ErrorResponse.from_dict(response.json())

        return response_422
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[ErrorResponse, List["DatapointSummaryItem"]]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    json_body: SummaryDatapointSearch,
    api_key: str,
) -> Response[Union[ErrorResponse, List["DatapointSummaryItem"]]]:
    """Get Datapoints Summary

     Expects a date range and returns a summary of datapoint counts by day and feedback range.

    Returns:
        list: An array of datapoint objects.

    Args:
        api_key (str):
        json_body (SummaryDatapointSearch):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[ErrorResponse, List['DatapointSummaryItem']]]
    """

    kwargs = _get_kwargs(
        json_body=json_body,
        api_key=api_key,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: Union[AuthenticatedClient, Client],
    json_body: SummaryDatapointSearch,
    api_key: str,
) -> Optional[Union[ErrorResponse, List["DatapointSummaryItem"]]]:
    """Get Datapoints Summary

     Expects a date range and returns a summary of datapoint counts by day and feedback range.

    Returns:
        list: An array of datapoint objects.

    Args:
        api_key (str):
        json_body (SummaryDatapointSearch):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[ErrorResponse, List['DatapointSummaryItem']]
    """

    return sync_detailed(
        client=client,
        json_body=json_body,
        api_key=api_key,
    ).parsed


async def asyncio_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    json_body: SummaryDatapointSearch,
    api_key: str,
) -> Response[Union[ErrorResponse, List["DatapointSummaryItem"]]]:
    """Get Datapoints Summary

     Expects a date range and returns a summary of datapoint counts by day and feedback range.

    Returns:
        list: An array of datapoint objects.

    Args:
        api_key (str):
        json_body (SummaryDatapointSearch):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[ErrorResponse, List['DatapointSummaryItem']]]
    """

    kwargs = _get_kwargs(
        json_body=json_body,
        api_key=api_key,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: Union[AuthenticatedClient, Client],
    json_body: SummaryDatapointSearch,
    api_key: str,
) -> Optional[Union[ErrorResponse, List["DatapointSummaryItem"]]]:
    """Get Datapoints Summary

     Expects a date range and returns a summary of datapoint counts by day and feedback range.

    Returns:
        list: An array of datapoint objects.

    Args:
        api_key (str):
        json_body (SummaryDatapointSearch):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[ErrorResponse, List['DatapointSummaryItem']]
    """

    return (
        await asyncio_detailed(
            client=client,
            json_body=json_body,
            api_key=api_key,
        )
    ).parsed
